"""Support pylint in Pylama."""

# Module information
# ==================


__version__ = "0.0.2"
__project__ = "pylava_pylint"
__author__ = "Pylava Developers"
__license__ = "MIT"

from .main import Linter  # noqa
